==> A.i386-unknown-freebsdelf3.3.tar.gz: A.i386-unknown-freebsdelf3.3/dbgcf.h <==

#define HOST_CPU "i386"
#define HOST_VENDOR "unknown"
#define HOST_OS "freebsdelf3.3"
#define HOST_OS_NAME "freebsdelf3"
#define HOST_OS_VERSION "3.3"
#define HOST_ARCH "i386"
#define HOST_NAME "ape.mcl.cs.columbia.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Mon Apr  3 19:35:29 EDT 2000"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s4"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s4"
#define DEBUG 1
#define HOST_HEADER_VERSION "3.3"
#define YYTEXT_POINTER 1
#define HAVE_LIBRPCSVC 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_CLOCK_GETTIME 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETMNTINFO 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UNMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_ATTRSTAT 1
#define HAVE_XDR_CREATEARGS 1
#define HAVE_XDR_DIRLIST 1
#define HAVE_XDR_DIROPARGS 1
#define HAVE_XDR_DIROPOKRES 1
#define HAVE_XDR_DIROPRES 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_ENTRY 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FATTR 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_FILENAME 1
#define HAVE_XDR_FTYPE 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_LINKARGS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_NFS_FH 1
#define HAVE_XDR_NFSCOOKIE 1
#define HAVE_XDR_NFSPATH 1
#define HAVE_XDR_NFSSTAT 1
#define HAVE_XDR_NFSTIME 1
#define HAVE_XDR_POINTER 1
#define HAVE_XDR_READARGS 1
#define HAVE_XDR_READDIRARGS 1
#define HAVE_XDR_READDIRRES 1
#define HAVE_XDR_READLINKRES 1
#define HAVE_XDR_READOKRES 1
#define HAVE_XDR_READRES 1
#define HAVE_XDR_RENAMEARGS 1
#define HAVE_XDR_SATTR 1
#define HAVE_XDR_SATTRARGS 1
#define HAVE_XDR_STATFSOKRES 1
#define HAVE_XDR_STATFSRES 1
#define HAVE_XDR_SYMLINKARGS 1
#define HAVE_XDR_WRITEARGS 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
#define HAVE_MACHINE_ENDIAN_H 1
#define HAVE_MSDOSFS_MSDOSFSMOUNT_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_IF_VAR_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFSMOUNT_H 1
#define HAVE_NFS_NFSPROTO_H 1
#define HAVE_NFS_NFSV2_H 1
#define HAVE_NFS_RPCV2_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_SOCKIO_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLIMITS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UCRED_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_UFS_UFS_UFSMOUNT_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define am_nfs_fh3 nfs_fh3_freebsd3
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct iso_args
#define mfs_args_t struct mfs_args
#define pcfs_args_t struct msdosfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define voidp void *
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GET_MYADDRESS 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_UNISTD_H 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
#define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_CDFS_ARGS_T_SSECTOR 1
#define HAVE_FIELD_PCFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_PCFS_ARGS_T_GID 1
#define HAVE_FIELD_PCFS_ARGS_T_MASK 1
#define HAVE_FIELD_PCFS_ARGS_T_UID 1
#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_PROTO 1
#define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_MFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_PCFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_UNIONFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS "nfs"
#define MOUNT_TYPE_NFS3 MOUNT_NFS3
#define MOUNT_TYPE_UFS "ufs"
#define MOUNT_TYPE_CDFS "cd9660"
#define MOUNT_TYPE_PCFS "msdos"
#define MOUNT_TYPE_MFS "mfs"
#define MOUNT_TYPE_UNIONFS MNT_UNION
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs3"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cd9660"
#define MNTTAB_TYPE_PCFS "msdos"
#define MNTTAB_TYPE_MFS "mfs"
#define MNTTAB_TYPE_UNIONFS "unionfs"
#define MNT2_GEN_OPT_ASYNC 0x40
#define MNT2_GEN_OPT_NODEV 0x10
#define MNT2_GEN_OPT_NOEXEC 0x4
#define MNT2_GEN_OPT_NOSUID 0x8
#define MNT2_GEN_OPT_QUOTA 0x2000
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
#define MNT2_NFS_OPT_ACDIRMAX 0x200000
#define MNT2_NFS_OPT_ACDIRMIN 0x100000
#define MNT2_NFS_OPT_ACREGMAX 0x80000
#define MNT2_NFS_OPT_ACREGMIN 0x40000
#define MNT2_NFS_OPT_DEADTHRESH 0x4000
#define MNT2_NFS_OPT_DUMBTIMR 0x800
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_LEASETERM 0x1000
#define MNT2_NFS_OPT_MAXGRPS 0x20
#define MNT2_NFS_OPT_NFSV3 0x200
#define MNT2_NFS_OPT_NOCONN 0x80
#define MNT2_NFS_OPT_NQNFS 0x100
#define MNT2_NFS_OPT_READAHEAD 0x2000
#define MNT2_NFS_OPT_RESVPORT 0x8000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define MNT2_CDFS_OPT_EXTATT 0x4
#define MNT2_CDFS_OPT_GENS 0x2
#define MNT2_CDFS_OPT_NORRIP 0x1
#define HIDE_MOUNT_TYPE "nfs"
#define USE_CONNECTED_NFS_SOCKETS 1

==> A.i386-unknown-freebsdelf3.4.tar.gz: A.i386-unknown-freebsdelf3.4/dbgcf.h <==

#define HOST_CPU "i386"
#define HOST_VENDOR "unknown"
#define HOST_OS "freebsdelf3.4"
#define HOST_OS_NAME "freebsdelf3"
#define HOST_OS_VERSION "3.4"
#define HOST_ARCH "i386"
#define HOST_NAME "newt.mcl.cs.columbia.edu"
#define USER_NAME "ezk"
#define CONFIG_DATE "Mon Apr  3 19:36:19 EDT 2000"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s4"
#define PACKAGE "am-utils"
#define VERSION "6.0.4s4"
#define DEBUG 1
#define HOST_HEADER_VERSION "3.4"
#define YYTEXT_POINTER 1
#define HAVE_LIBRPCSVC 1
#define HAVE_ALLOCA 1
#define STDC_HEADERS 1
#define HAVE_WAIT3 1
#define HAVE__SETERR_REPLY 1
#define HAVE_BCMP 1
#define HAVE_BCOPY 1
#define HAVE_BZERO 1
#define HAVE_CLNT_CREATE 1
#define HAVE_CLNT_SPCREATEERROR 1
#define HAVE_CLOCK_GETTIME 1
#define HAVE_FLOCK 1
#define HAVE_GET_MYADDRESS 1
#define HAVE_GETCWD 1
#define HAVE_GETDOMAINNAME 1
#define HAVE_GETDTABLESIZE 1
#define HAVE_GETHOSTNAME 1
#define HAVE_GETMNTINFO 1
#define HAVE_GETPAGESIZE 1
#define HAVE_GETTIMEOFDAY 1
#define HAVE_MEMCMP 1
#define HAVE_MEMCPY 1
#define HAVE_MEMMOVE 1
#define HAVE_MEMSET 1
#define HAVE_MKDIR 1
#define HAVE_MKSTEMP 1
#define HAVE_MOUNT 1
#define HAVE_REGCOMP 1
#define HAVE_REGEXEC 1
#define HAVE_RMDIR 1
#define HAVE_SELECT 1
#define HAVE_SETEUID 1
#define HAVE_SETITIMER 1
#define HAVE_SETSID 1
#define HAVE_SIGACTION 1
#define HAVE_SIGNAL 1
#define HAVE_SOCKET 1
#define HAVE_STRCHR 1
#define HAVE_STRCSPN 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRERROR 1
#define HAVE_STRSPN 1
#define HAVE_STRSTR 1
#define HAVE_SVC_GETREQ 1
#define HAVE_SVC_GETREQSET 1
#define HAVE_SYSLOG 1
#define HAVE_UNAME 1
#define HAVE_UNMOUNT 1
#define HAVE_VFORK 1
#define HAVE_VSNPRINTF 1
#define HAVE_WAIT3 1
#define HAVE_WAITPID 1
#define HAVE_CLNT_SPERRNO 1
#define HAVE_STRCASECMP 1
#define HAVE_STRDUP 1
#define HAVE_STRSTR 1
#define HAVE_UALARM 1
#define HAVE_XDR_ATTRSTAT 1
#define HAVE_XDR_CREATEARGS 1
#define HAVE_XDR_DIRLIST 1
#define HAVE_XDR_DIROPARGS 1
#define HAVE_XDR_DIROPOKRES 1
#define HAVE_XDR_DIROPRES 1
#define HAVE_XDR_DIRPATH 1
#define HAVE_XDR_ENTRY 1
#define HAVE_XDR_EXPORTNODE 1
#define HAVE_XDR_EXPORTS 1
#define HAVE_XDR_FATTR 1
#define HAVE_XDR_FHANDLE 1
#define HAVE_XDR_FHSTATUS 1
#define HAVE_XDR_FILENAME 1
#define HAVE_XDR_FTYPE 1
#define HAVE_XDR_GROUPNODE 1
#define HAVE_XDR_GROUPS 1
#define HAVE_XDR_LINKARGS 1
#define HAVE_XDR_MOUNTBODY 1
#define HAVE_XDR_MOUNTLIST 1
#define HAVE_XDR_NAME 1
#define HAVE_XDR_NFS_FH 1
#define HAVE_XDR_NFSCOOKIE 1
#define HAVE_XDR_NFSPATH 1
#define HAVE_XDR_NFSSTAT 1
#define HAVE_XDR_NFSTIME 1
#define HAVE_XDR_POINTER 1
#define HAVE_XDR_READARGS 1
#define HAVE_XDR_READDIRARGS 1
#define HAVE_XDR_READDIRRES 1
#define HAVE_XDR_READLINKRES 1
#define HAVE_XDR_READOKRES 1
#define HAVE_XDR_READRES 1
#define HAVE_XDR_RENAMEARGS 1
#define HAVE_XDR_SATTR 1
#define HAVE_XDR_SATTRARGS 1
#define HAVE_XDR_STATFSOKRES 1
#define HAVE_XDR_STATFSRES 1
#define HAVE_XDR_SYMLINKARGS 1
#define HAVE_XDR_WRITEARGS 1
#define HAVE_DIRENT_H 1
#define STDC_HEADERS 1
#define HAVE_SYS_WAIT_H 1
#define HAVE_ARPA_NAMESER_H 1
#define HAVE_ARPA_INET_H 1
#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
#define HAVE_MACHINE_ENDIAN_H 1
#define HAVE_MSDOSFS_MSDOSFSMOUNT_H 1
#define HAVE_NET_IF_H 1
#define HAVE_NET_IF_VAR_H 1
#define HAVE_NET_ROUTE_H 1
#define HAVE_NETINET_IF_ETHER_H 1
#define HAVE_NETINET_IN_H 1
#define HAVE_NFS_NFS_H 1
#define HAVE_NFS_NFSMOUNT_H 1
#define HAVE_NFS_NFSPROTO_H 1
#define HAVE_NFS_NFSV2_H 1
#define HAVE_NFS_RPCV2_H 1
#define HAVE_RPC_AUTH_DES_H 1
#define HAVE_RPC_PMAP_CLNT_H 1
#define HAVE_RPC_PMAP_PROT_H 1
#define HAVE_RPC_RPC_H 1
#define HAVE_RPC_TYPES_H 1
#define HAVE_RPC_XDR_H 1
#define HAVE_RPCSVC_MOUNT_H 1
#define HAVE_RPCSVC_NFS_PROT_H 1
#define HAVE_RPCSVC_NIS_H 1
#define HAVE_RPCSVC_YP_PROT_H 1
#define HAVE_RPCSVC_YPCLNT_H 1
#define HAVE_SYS_ERRNO_H 1
#define HAVE_SYS_FILE_H 1
#define HAVE_SYS_IOCTL_H 1
#define HAVE_SYS_LOCK_H 1
#define HAVE_SYS_MBUF_H 1
#define HAVE_SYS_MOUNT_H 1
#define HAVE_SYS_PARAM_H 1
#define HAVE_SYS_PROC_H 1
#define HAVE_SYS_RESOURCE_H 1
#define HAVE_SYS_SIGNAL_H 1
#define HAVE_SYS_SOCKET_H 1
#define HAVE_SYS_SOCKIO_H 1
#define HAVE_SYS_STAT_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYS_SYSLIMITS_H 1
#define HAVE_SYS_SYSLOG_H 1
#define HAVE_SYS_TIME_H 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_UCRED_H 1
#define HAVE_SYS_UIO_H 1
#define HAVE_SYS_UTSNAME_H 1
#define HAVE_SYS_VNODE_H 1
#define HAVE_UFS_UFS_UFSMOUNT_H 1
#define HAVE_ASSERT_H 1
#define HAVE_CTYPE_H 1
#define HAVE_ERRNO_H 1
#define HAVE_FCNTL_H 1
#define HAVE_GRP_H 1
#define HAVE_MEMORY_H 1
#define HAVE_NDBM_H 1
#define HAVE_NETDB_H 1
#define HAVE_PWD_H 1
#define HAVE_REGEX_H 1
#define HAVE_RESOLV_H 1
#define HAVE_SETJMP_H 1
#define HAVE_SIGNAL_H 1
#define HAVE_STDARG_H 1
#define HAVE_STDLIB_H 1
#define HAVE_STDIO_H 1
#define HAVE_STRING_H 1
#define HAVE_STRINGS_H 1
#define HAVE_SYSLOG_H 1
#define HAVE_TIME_H 1
#define HAVE_VARARGS_H 1
#define HAVE_UNISTD_H 1
#define TIME_WITH_SYS_TIME 1
#define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_freebsd3.h"
#define HAVE_STRUCT_NFS_ARGS 1
#define nfs_args_t struct nfs_args
#define NFS_FH_FIELD fh
#define am_nfs_fh nfs_fh
#define am_nfs_fh3 nfs_fh3_freebsd3
#define GETGROUPS_T gid_t
#define RETSIGTYPE void
#define HAVE_FHANDLE 1
#define MTYPE_TYPE char *
#define MTYPE_PRINTF_TYPE "%s"
#define YP_ORDER_OUTORDER_TYPE int
#define RECVFROM_FROMLEN_TYPE int
#define AUTH_CREATE_GIDLIST_TYPE gid_t
#define SVC_IN_ARG_TYPE caddr_t
#define cdfs_args_t struct iso_args
#define mfs_args_t struct mfs_args
#define pcfs_args_t struct msdosfs_args
#define ufs_args_t struct ufs_args
#define XDRPROC_T_TYPE xdrproc_t
#define voidp void *
#define HAVE_EXTERN_SYS_ERRLIST 1
#define HAVE_EXTERN_OPTARG 1
#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
#define HAVE_EXTERN_CLNT_SPERRNO 1
#define HAVE_EXTERN_FREE 1
#define HAVE_EXTERN_GET_MYADDRESS 1
#define HAVE_EXTERN_GETDOMAINNAME 1
#define HAVE_EXTERN_GETDTABLESIZE 1
#define HAVE_EXTERN_GETHOSTNAME 1
#define HAVE_EXTERN_GETLOGIN 1
#define HAVE_EXTERN_GETPAGESIZE 1
#define HAVE_EXTERN_GETWD 1
#define HAVE_EXTERN_MKSTEMP 1
#define HAVE_EXTERN_SBRK 1
#define HAVE_EXTERN_SETEUID 1
#define HAVE_EXTERN_SETITIMER 1
#define HAVE_EXTERN_STRCASECMP 1
#define HAVE_EXTERN_STRDUP 1
#define HAVE_EXTERN_STRSTR 1
#define HAVE_EXTERN_UALARM 1
#define HAVE_EXTERN_USLEEP 1
#define HAVE_EXTERN_WAIT3 1
#define HAVE_EXTERN_VSNPRINTF 1
#define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
#define HAVE_LONG_FILE_NAMES 1
#define HAVE_UNISTD_H 1
#define HAVE_RESTARTABLE_SYSCALLS 1
#define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
#define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_CDFS_ARGS_T_SSECTOR 1
#define HAVE_FIELD_PCFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_PCFS_ARGS_T_GID 1
#define HAVE_FIELD_PCFS_ARGS_T_MASK 1
#define HAVE_FIELD_PCFS_ARGS_T_UID 1
#define HAVE_FIELD_UFS_ARGS_T_FSPEC 1
#define HAVE_FIELD_STRUCT_STATFS_F_FSTYPENAME 1
#define HAVE_FIELD_NFS_ARGS_T_ACDIRMIN 1
#define HAVE_FIELD_NFS_ARGS_T_ACREGMIN 1
#define HAVE_FIELD_NFS_ARGS_T_FHSIZE 1
#define HAVE_FIELD_NFS_ARGS_T_PROTO 1
#define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
#define HAVE_FIELD_NFS_ARGS_T_VERSION 1
#define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
#define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
#define HAVE_MAP_FILE 1
#define HAVE_MAP_NDBM 1
#define HAVE_MAP_NIS 1
#define HAVE_MAP_PASSWD 1
#define HAVE_MAP_UNION 1
#define HAVE_FS_CDFS 1
#define HAVE_FS_MFS 1
#define HAVE_FS_NFS 1
#define HAVE_FS_NFS3 1
#define HAVE_FS_PCFS 1
#define HAVE_FS_UFS 1
#define HAVE_FS_UNIONFS 1
#define HAVE_AMU_FS_AUTO 1
#define HAVE_AMU_FS_DIRECT 1
#define HAVE_AMU_FS_TOPLVL 1
#define HAVE_AMU_FS_ERROR 1
#define HAVE_AMU_FS_INHERIT 1
#define HAVE_AMU_FS_PROGRAM 1
#define HAVE_AMU_FS_LINK 1
#define HAVE_AMU_FS_LINKX 1
#define HAVE_AMU_FS_HOST 1
#define HAVE_AMU_FS_NFSX 1
#define HAVE_AMU_FS_NFSL 1
#define HAVE_AMU_FS_UNION 1
#define MOUNT_TYPE_NFS "nfs"
#define MOUNT_TYPE_NFS3 MOUNT_NFS3
#define MOUNT_TYPE_UFS "ufs"
#define MOUNT_TYPE_CDFS "cd9660"
#define MOUNT_TYPE_PCFS "msdos"
#define MOUNT_TYPE_MFS "mfs"
#define MOUNT_TYPE_UNIONFS MNT_UNION
#define MNTTAB_TYPE_NFS "nfs"
#define MNTTAB_TYPE_NFS3 "nfs3"
#define MNTTAB_TYPE_UFS "ufs"
#define MNTTAB_TYPE_CDFS "cd9660"
#define MNTTAB_TYPE_PCFS "msdos"
#define MNTTAB_TYPE_MFS "mfs"
#define MNTTAB_TYPE_UNIONFS "unionfs"
#define MNT2_GEN_OPT_ASYNC 0x40
#define MNT2_GEN_OPT_NODEV 0x10
#define MNT2_GEN_OPT_NOEXEC 0x4
#define MNT2_GEN_OPT_NOSUID 0x8
#define MNT2_GEN_OPT_QUOTA 0x2000
#define MNT2_GEN_OPT_RDONLY 0x1
#define MNT2_GEN_OPT_SYNCHRONOUS 0x2
#define MNT2_NFS_OPT_ACDIRMAX 0x200000
#define MNT2_NFS_OPT_ACDIRMIN 0x100000
#define MNT2_NFS_OPT_ACREGMAX 0x80000
#define MNT2_NFS_OPT_ACREGMIN 0x40000
#define MNT2_NFS_OPT_DEADTHRESH 0x4000
#define MNT2_NFS_OPT_DUMBTIMR 0x800
#define MNT2_NFS_OPT_INT 0x40
#define MNT2_NFS_OPT_LEASETERM 0x1000
#define MNT2_NFS_OPT_MAXGRPS 0x20
#define MNT2_NFS_OPT_NFSV3 0x200
#define MNT2_NFS_OPT_NOCONN 0x80
#define MNT2_NFS_OPT_NQNFS 0x100
#define MNT2_NFS_OPT_READAHEAD 0x2000
#define MNT2_NFS_OPT_RESVPORT 0x8000
#define MNT2_NFS_OPT_RETRANS 0x10
#define MNT2_NFS_OPT_RSIZE 0x4
#define MNT2_NFS_OPT_SOFT 0x1
#define MNT2_NFS_OPT_TIMEO 0x8
#define MNT2_NFS_OPT_WSIZE 0x2
#define MNT2_CDFS_OPT_EXTATT 0x4
#define MNT2_CDFS_OPT_GENS 0x2
#define MNT2_CDFS_OPT_NORRIP 0x1
#define HIDE_MOUNT_TYPE "nfs"
#define USE_CONNECTED_NFS_SOCKETS 1
